<?php

class cf_tcpdf extends TCPDF
{
    private $logoSVG = FCPATH . 'public/images/CFEngine_enterprise_logo.svg';
    private $currentY;
    private $pageWidthPx = 756;
    private $imgHeight = 40;

    public function printHeader($reportTitle, $description)
    {
        if ($customLogo = trim(getCustomLogoFile('logo_on_pdf'), '/')) {
            [$width, $height] = getimagesize($customLogo);
            // convert pixels to mm, multiplying by 0.264
            //  x = page width (756) - image width * (ratio) and convert to mm
            $this->Image(
                $customLogo,
                $x = $this->pixelsToMM($this->pageWidthPx - ($width * 40 / $height)),
                $y = 3,
                $w = '',
                $h = $this->pixelsToMM($this->imgHeight)
            );
        } else {
            $this->ImageSVG(
                $this->logoSVG,
                $x = $this->pixelsToMM(($this->pageWidthPx - 124)),
                $y = 3,
                $w = '',
                $h = $this->pixelsToMM($this->imgHeight)
            );
        }

        $this->currentY = $this->pixelsToMM($this->imgHeight) + 10;
        date_default_timezone_set('UTC');
        $time = '<i style="color: #0B132A;font-size: 10px;">' . date('Y-m-d H:i:s T', time()) . '</i>';
        $this->SetY($this->currentY);
        $this->SetLeftMargin($this->pixelsToMM($this->pageWidthPx - 155)); // place time on the right side, 250 is the time text size
        $this->writeHTML($time);

        $this->currentY = 5.25;
        $this->SetLeftMargin(10);
        $this->SetXY(15, $this->currentY);
        $this->SetRightMargin($this->pixelsToMM(330)); // set right margin to avoid description overlapping with logo and time
        $title = "<h3>{$reportTitle}</h3><div style=\"color: #a5a5a5;\">{$description}</div>";
        $this->writeHTML($title);
        // every line has 50 characters
        $descLines = ceil(strlen($description) / 50);
        // calculate description height
        $descHeight = $descLines * 6 + 10;
        // add title size to Y
        $this->currentY += $descHeight > 30 ? $descHeight : 30;

        $this->SetY($this->currentY);
        $this->SetRightMargin(10);
        $this->writeHTML('<hr />', true, false, true, false, '');
        $this->currentY += 10;
    }

    private function pixelsToMM($px) {
        return $px * 0.264;
    }

}
